==========================
SEAMM Forcefield Utilities
==========================

.. image:: https://img.shields.io/travis/molssi-seamm/seamm_ff_util.svg
   :target: https://travis-ci.org/molssi-seamm/seamm_ff_util
   :alt: Build Status

.. image:: https://codecov.io/gh/molssi-seamm/seamm_ff_util/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/molssi-seamm/seamm_ff_util
   :alt: Code Coverage

.. image:: https://github.com/molssi-seamm/seamm_ff_util/workflows/CodeQL/badge.svg
   :target: https://github.com/molssi-seamm/seamm_ff_util/security/code-scanning
   :alt: Code Quality

.. image:: https://github.com/molssi-seamm/seamm_ff_util/workflows/Release/badge.svg
   :target: https://molssi-seamm.github.io/seamm_ff_util/index.html
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/seamm_ff_util.svg
   :target: https://pypi.python.org/pypi/seamm_ff_util
   :alt: PyPi VERSION

The SEAMM Forcefield Utilities read and write forcefields, assigns them to molecules, and creates energy expressions.


* Free software: BSD license
* Documentation: https://seamm_ff_util.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `molssi-seamm/cookiecutter-seamm-plugin`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`molssi-seamm/cookiecutter-seamm-plugin`: https://github.com/molssi-seamm/cookiecutter-seamm-plugin

Developed by the Molecular Sciences Software Institute (MolSSI_),
which receives funding from the `National Science Foundation`_ under
award OAC-1547580 and CHE-2136142.

.. _MolSSI: https://www.molssi.org
.. _`National Science Foundation`: https://www.nsf.gov
